Coverage report

# Coverage report: 21%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 140 | 111 | 0 | 21%
conftest.py | 60 | 38 | 0 | 37%
test_asg.py | 5 | 5 | 0 | 0%
test_cli.py | 5 | 5 | 0 | 0%
test_ec2.py | 51 | 51 | 0 | 0%
test_elb.py | 8 | 8 | 0 | 0%
test_emr.py | 11 | 4 | 0 | 64%

No items found using the specified filter.